@@ -17,7 +17,8 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
-#include <KToolInvocation>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
 #include <QMenu>
 
 AlarmDockWindow::AlarmDockWindow()
@@ -38,17 +39,12 @@ AlarmDockWindow::AlarmDockWindow()
     setTitle(mName);
 
     // Set up icons
-    KIconLoader::global()->addAppDir(QStringLiteral("korgac"));
-    const QString iconPath = KIconLoader::global()->iconPath(QStringLiteral("korgac"), KIconLoader::Panel);
-    const QIcon iconEnabled = QIcon(iconPath);
-    if (iconEnabled.isNull()) {
-        KMessageBox::sorry(associatedWidget(), i18nc("@info", "Cannot load system tray icon."));
-    } else {
-        KIconLoader loader;
-        QImage iconDisabled = iconEnabled.pixmap(loader.currentSize(KIconLoader::Panel)).toImage();
-        KIconEffect::toGray(iconDisabled, 1.0);
-        mIconDisabled = QIcon(QPixmap::fromImage(iconDisabled));
-    }
+    const QIcon iconEnabled = QIcon::fromTheme(QStringLiteral("korgac"));
+
+    KIconLoader loader;
+    QImage iconDisabled = iconEnabled.pixmap(loader.currentSize(KIconLoader::Panel)).toImage();
+    KIconEffect::toGray(iconDisabled, 1.0);
+    mIconDisabled = QIcon(QPixmap::fromImage(iconDisabled));
 
     changeSystrayIcon(alarmsEnabled);
 
@@ -154,7 +150,7 @@ void AlarmDockWindow::enableAutostart(bool enable)
 void AlarmDockWindow::activate(const QPoint &pos)
 {
     Q_UNUSED(pos)
-    KToolInvocation::startServiceByDesktopName(QStringLiteral("org.kde.korganizer"), QString());
+    QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.korganizer"));
 }
 
 void AlarmDockWindow::slotQuit()
