@@ -35,10 +35,10 @@
 
 #include <Akonadi/Calendar/History>
 #include <Akonadi/Calendar/ICalImporter>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiWidgets/ETMViewStateSaver>
-#include <AkonadiWidgets/EntityTreeView>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/EntityTreeView>
 
 #include <KCalendarCore/FileStorage>
 #include <KCalendarCore/ICalFormat>
@@ -100,9 +100,6 @@ ActionManager::ActionManager(KXMLGUIClient *client,
 
 ActionManager::~ActionManager()
 {
-    // Remove Part plugins
-    KOCore::self()->unloadParts(mMainWindow, mParts);
-
     delete mTempFile;
 
     // Take this window out of the window list.
@@ -999,8 +996,6 @@ void ActionManager::updateConfig()
         korgacInterface.show();
     }
 
-// Commented out because it crashes KOrganizer.
-//  mParts = KOCore::self()->reloadParts( mMainWindow, mParts );
 #ifdef AKONADI_PORT_DISABLED // shouldn't be required anymore
     if (mCollectionView) {
         mCollectionView->updateView();
@@ -1340,19 +1335,9 @@ void ActionManager::keyBindings()
         dlg.addCollection(mMainWindow->getActionCollection());
     }
 
-    for (KOrg::Part *part : std::as_const(mParts)) {
-        if (part) {
-            dlg.addCollection(part->actionCollection(), part->shortInfo());
-        }
-    }
     dlg.configure();
 }
 
-void ActionManager::loadParts()
-{
-    mParts = KOCore::self()->loadParts(mMainWindow);
-}
-
 void ActionManager::setTitle()
 {
     mMainWindow->setTitle();
@@ -1383,6 +1368,8 @@ void ActionManager::openEventEditor(const QString &summary,
     int action = IncidenceEditorNG::IncidenceEditorSettings::self()->defaultEmailAttachMethod();
     if (attachmentMimetype != QLatin1String("message/rfc822")) {
         action = IncidenceEditorNG::IncidenceEditorSettings::Link;
+    } else if (file.isEmpty()) {
+        action = KOPrefs::TodoAttachLink;
     } else if (IncidenceEditorNG::IncidenceEditorSettings::self()->defaultEmailAttachMethod() == IncidenceEditorNG::IncidenceEditorSettings::Ask) {
         auto menu = new QMenu(nullptr);
         QAction *attachLink = menu->addAction(i18n("Attach as &link"));
@@ -1487,6 +1474,8 @@ void ActionManager::openTodoEditor(const QString &summary,
     int action = KOPrefs::instance()->defaultTodoAttachMethod();
     if (attachmentMimetype != QLatin1String("message/rfc822")) {
         action = KOPrefs::TodoAttachLink;
+    } else if (file.isEmpty()) {
+        action = KOPrefs::TodoAttachLink;
     } else if (KOPrefs::instance()->defaultTodoAttachMethod() == KOPrefs::TodoAttachAsk) {
         auto menu = new QMenu(nullptr);
         QAction *attachLink = menu->addAction(i18n("Attach as &link"));
