@@ -8,12 +8,11 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_AKONADICOLLECTIONVIEW_H
-#define KORG_AKONADICOLLECTIONVIEW_H
+#pragma once
 
 #include "calendarview.h"
 #include "views/collectionview/reparentingmodel.h"
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 
 class AkonadiCollectionView;
 class ManageShowCollectionProperties;
@@ -110,4 +109,3 @@ private:
     ManageShowCollectionProperties *mManagerShowCollectionProperties = nullptr;
 };
 
-#endif
