@@ -32,8 +32,8 @@
 #include "views/todoview/kotodoview.h"
 #include "widgets/navigatorbar.h"
 
-#include <AkonadiCore/AttributeFactory>
-#include <AkonadiCore/CollectionIdentificationAttribute>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/CollectionIdentificationAttribute>
 
 #include <Akonadi/Calendar/CalendarClipboard>
 #include <Akonadi/Calendar/FreeBusyManager>
@@ -41,9 +41,9 @@
 #include <Akonadi/Calendar/TodoPurger>
 #include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
 
-#include <AkonadiWidgets/CollectionMaintenancePage>
-#include <AkonadiWidgets/CollectionPropertiesDialog>
-#include <AkonadiWidgets/ControlGui>
+#include <Akonadi/CollectionMaintenancePage>
+#include <Akonadi/CollectionPropertiesDialog>
+#include <Akonadi/ControlGui>
 
 #include <CalendarSupport/CalPrinter>
 #include <CalendarSupport/CalendarSingleton>
@@ -216,7 +216,7 @@ CalendarView::CalendarView(QWidget *parent)
     connect(mDateNavigatorContainer,
             &DateNavigatorContainer::datesSelected,
             mDateNavigator,
-            QOverload<const KCalendarCore::DateList &, QDate>::of(&DateNavigator::selectDates));
+            qOverload<const KCalendarCore::DateList &, QDate>(&DateNavigator::selectDates));
 
     connect(mViewManager, &KOViewManager::datesSelected, mDateNavigator, [this](const KCalendarCore::DateList &dates) {
         mDateNavigator->selectDates(dates);
@@ -539,15 +539,6 @@ void CalendarView::goPrevious()
 
 void CalendarView::updateConfig()
 {
-    updateConfig(QByteArray("korganizer"));
-}
-
-void CalendarView::updateConfig(const QByteArray &receiver)
-{
-    if (receiver != "korganizer") {
-        return;
-    }
-
     if (mCalPrinter) {
         mCalPrinter->deleteLater();
         mCalPrinter = nullptr;
@@ -970,28 +961,18 @@ void CalendarView::newEvent(const QString &summary,
                             const QStringList &attachmentMimetypes,
                             bool inlineAttachment)
 {
-    // Adjust the start/end date times (i.e. replace invalid values by defaults,
-    // and let the view adjust the type.
-    QDateTime startDt;
-    QDateTime endDt;
-    bool allDay = false;
-    dateTimesForNewEvent(startDt, endDt, allDay);
+    Akonadi::Collection defaultCol = defaultCollection(KCalendarCore::Event::eventMimeType());
 
-    IncidenceEditorNG::IncidenceDefaults defaults = IncidenceEditorNG::IncidenceDefaults::minimalIncidenceDefaults();
-    defaults.setStartDateTime(startDt);
-    defaults.setEndDateTime(endDt);
-    // if attach or attendee list is empty, these methods don't do anything, so
-    // it's safe to call them in every case
-    defaults.setAttachments(attachments, attachmentMimetypes, QStringList(), inlineAttachment);
-    defaults.setAttendees(attendees);
-
-    KCalendarCore::Event::Ptr event(new KCalendarCore::Event);
-    defaults.setDefaults(event);
-
-    event->setSummary(summary);
-    event->setDescription(description);
-    event->setAllDay(allDay);
-    newEventEditor(event);
+    IncidenceEditorNG::IncidenceDialogFactory::createEventEditor(summary,
+                                                                 description,
+                                                                 attachments,
+                                                                 attendees,
+                                                                 attachmentMimetypes,
+                                                                 QStringList() /* attachment labels */,
+                                                                 inlineAttachment,
+                                                                 defaultCol,
+                                                                 true /* cleanupAttachmentTempFiles */,
+                                                                 this /* parent */);
 }
 
 void CalendarView::newTodo(const QString &summary,
@@ -1275,8 +1256,8 @@ bool CalendarView::makeChildrenIndependent(const Akonadi::Item &item)
         return false;
     }
 
-    for (const Akonadi::Item &item : subIncs) {
-        incidence_unsub(item);
+    for (const Akonadi::Item &subInc : subIncs) {
+        incidence_unsub(subInc);
     }
 
     return true;
@@ -1729,7 +1710,11 @@ void CalendarView::exportICalendar()
         }
 
         if (QFileInfo::exists(filename)) {
-            if (KMessageBox::No == KMessageBox::warningYesNo(this, i18n("Do you want to overwrite %1?", filename))) {
+            const int answer = KMessageBox::warningContinueCancel(this,
+                                                                  i18n("Do you want to overwrite %1?", filename),
+                                                                  i18nc("@title:window", "Export Calendar"),
+                                                                  KStandardGuiItem::overwrite());
+            if (answer == KMessageBox::Cancel) {
                 return;
             }
         }
