@@ -10,7 +10,7 @@
 
 #pragma once
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <QDialog>
 
