@@ -9,8 +9,8 @@
 
 #include "korganizerifaceimpl.h"
 #include "actionmanager.h"
-#include "korganizeradaptor.h"
 #include "korganizer_debug.h"
+#include "korganizeradaptor.h"
 
 KOrganizerIfaceImpl::KOrganizerIfaceImpl(ActionManager *actionManager, QObject *parent, const QString &name)
     : QObject(parent)
@@ -18,8 +18,7 @@ KOrganizerIfaceImpl::KOrganizerIfaceImpl(ActionManager *actionManager, QObject *
 {
     setObjectName(name);
     new KorganizerAdaptor(this);
-    QDBusConnection::sessionBus().registerObject(
-        QStringLiteral("/Korganizer"), this, QDBusConnection::ExportAdaptors);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/Korganizer"), this, QDBusConnection::ExportAdaptors);
 }
 
 KOrganizerIfaceImpl::~KOrganizerIfaceImpl()
@@ -54,7 +53,7 @@ QString KOrganizerIfaceImpl::getCurrentURLasString() const
 bool KOrganizerIfaceImpl::deleteIncidence(const QString &uid, bool force)
 {
     bool ok;
-    qint64 id = QVariant(uid).toLongLong(&ok);
+    const qint64 id = QVariant(uid).toLongLong(&ok);
     if (!ok) {
         qCWarning(KORGANIZER_LOG) << "Invalid uid" << uid;
         return false;
@@ -65,7 +64,7 @@ bool KOrganizerIfaceImpl::deleteIncidence(const QString &uid, bool force)
 bool KOrganizerIfaceImpl::editIncidence(const QString &itemId)
 {
     bool ok;
-    qint64 id = QVariant(itemId).toLongLong(&ok);
+    const qint64 id = QVariant(itemId).toLongLong(&ok);
     if (!ok) {
         qCWarning(KORGANIZER_LOG) << "Invalid item id = " << itemId;
         return false;
@@ -81,7 +80,7 @@ bool KOrganizerIfaceImpl::addIncidence(const QString &uid)
 bool KOrganizerIfaceImpl::showIncidence(const QString &uid)
 {
     bool ok;
-    qint64 id = QVariant(uid).toLongLong(&ok);
+    const qint64 id = QVariant(uid).toLongLong(&ok);
     if (!ok) {
         qCWarning(KORGANIZER_LOG) << "Invalid uid" << uid;
         return false;
@@ -92,7 +91,7 @@ bool KOrganizerIfaceImpl::showIncidence(const QString &uid)
 bool KOrganizerIfaceImpl::showIncidenceContext(const QString &uid)
 {
     bool ok;
-    qint64 id = QVariant(uid).toLongLong(&ok);
+    const qint64 id = QVariant(uid).toLongLong(&ok);
     if (!ok) {
         qCWarning(KORGANIZER_LOG) << "Invalid uid" << uid;
         return false;
