@@ -17,13 +17,17 @@
 #include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/Calendar/IncidenceChanger>
 
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <QWidget>
 
+#include <memory>
+
 namespace KOrg
 {
+class BaseViewPrivate;
+
 /**
   This class provides an interface for all views being displayed within the
   main calendar view. It has functions to update the view, to specify date
@@ -381,9 +385,8 @@ protected:
     Akonadi::IncidenceChanger *mChanger = nullptr;
 
 private:
-    class Private;
-    Private *const d;
-    friend class KOrg::BaseView::Private;
+    std::unique_ptr<BaseViewPrivate> const d;
+    friend class KOrg::BaseViewPrivate;
 };
 }
 
