@@ -8,8 +8,9 @@
 
 #include "mainwindow.h"
 
-namespace KOrg {
-MainWindow::MainWindow() : mDocument(true)
+namespace KOrg
+{
+MainWindow::MainWindow()
 {
 }
 
@@ -19,7 +20,7 @@ MainWindow::~MainWindow()
 
 void MainWindow::init(bool hasDocument)
 {
-    Q_UNUSED(hasDocument);
+    Q_UNUSED(hasDocument)
 }
 
 void MainWindow::setHasDocument(bool d)
