@@ -22,8 +22,8 @@
 #include <QCommandLineParser>
 #include <QDBusConnectionInterface>
 
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include <KMessageBox>
 
