@@ -21,15 +21,12 @@
 #include <IncidenceEditor/IncidenceDialog>
 #include <IncidenceEditor/IncidenceDialogFactory>
 
-#include <AkonadiCore/Item>
-#include <AkonadiWidgets/TagManagementDialog>
+#include <Akonadi/Item>
+#include <Akonadi/TagManagementDialog>
 
 #include <KCalendarCore/Visitor>
 
-#include <kcmutils_version.h>
-
 #include <KCMultiDialog>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <QPushButton>
 
@@ -73,17 +70,10 @@ void KODialogManager::showOptionsDialog()
 {
     if (!mOptionsDialog) {
         mOptionsDialog = new KCMultiDialog(mMainView);
-        connect(mOptionsDialog,
-                qOverload<const QByteArray &>(&KCMultiDialog::configCommitted),
-                mMainView,
-                qOverload<const QByteArray &>(&CalendarView::updateConfig));
-        const QVector<KPluginMetaData> availablePlugins = KPluginLoader::findPlugins(QStringLiteral("pim/kcms/korganizer"));
+        connect(mOptionsDialog, qOverload<>(&KCMultiDialog::configCommitted), mMainView, &CalendarView::updateConfig);
+        const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/korganizer"));
         for (const KPluginMetaData &metaData : availablePlugins) {
-#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
             mOptionsDialog->addModule(metaData);
-#else
-            mOptionsDialog->addModule(metaData.pluginId());
-#endif
         }
     }
 
