@@ -45,7 +45,7 @@ KOEventView::~KOEventView()
 
 KOEventPopupMenu *KOEventView::eventPopup()
 {
-    KOEventPopupMenu *eventPopup = new KOEventPopupMenu(calendar(), this);
+    auto eventPopup = new KOEventPopupMenu(calendar(), this);
 
     connect(eventPopup, &KOEventPopupMenu::editIncidenceSignal, this, &KOEventView::editIncidenceSignal);
     connect(eventPopup, &KOEventPopupMenu::showIncidenceSignal, this, &KOEventView::showIncidenceSignal);
@@ -157,7 +157,7 @@ void KOEventView::focusChanged(QWidget *, QWidget *now)
 void KOEventView::finishTypeAhead()
 {
     if (mTypeAheadReceiver) {
-        for (QEvent *e : qAsConst(mTypeAheadEvents)) {
+        for (QEvent *e : std::as_const(mTypeAheadEvents)) {
             QApplication::sendEvent(mTypeAheadReceiver, e);
         }
     }
