@@ -17,7 +17,7 @@
 
 QColor KOHelper::getTextColor(const QColor &c)
 {
-    double luminance = (c.red() * 0.299) + (c.green() * 0.587) + (c.blue() * 0.114);
+    const double luminance = (c.red() * 0.299) + (c.green() * 0.587) + (c.blue() * 0.114);
     return (luminance > 128.0) ? QColor(0, 0, 0) : QColor(255, 255, 255);
 }
 
@@ -54,8 +54,5 @@ bool KOHelper::isStandardCalendar(Akonadi::Collection::Id id)
 
 void KOHelper::showSaveIncidenceErrorMsg(QWidget *parent, const KCalendarCore::Incidence::Ptr &incidence)
 {
-    KMessageBox::sorry(
-        parent,
-        i18n("Unable to save %1 \"%2\".",
-             i18n(incidence->typeStr().constData()), incidence->summary()));
+    KMessageBox::sorry(parent, i18n("Unable to save %1 \"%2\".", i18n(incidence->typeStr().constData()), incidence->summary()));
 }
