@@ -6,12 +6,11 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_KOHELPER_H
-#define KORG_KOHELPER_H
+#pragma once
 
 #include "korganizerprivate_export.h"
 
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 
 #include <KCalendarCore/Incidence>
 
@@ -61,4 +60,3 @@ KORGANIZERPRIVATE_EXPORT Q_REQUIRED_RESULT bool isStandardCalendar(Akonadi::Coll
 KORGANIZERPRIVATE_EXPORT void showSaveIncidenceErrorMsg(QWidget *parent, const KCalendarCore::Incidence::Ptr &incidence);
 }
 
-#endif
