@@ -21,34 +21,34 @@ K_PLUGIN_CLASS_WITH_JSON(KCMApptSummary, "kcmapptsummary.json")
 
 KCMApptSummary::KCMApptSummary(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
+    , mDaysButtonGroup(new QButtonGroup(this)) // krazy:exclude=tipsandthis
+    , mShowButtonGroup(new QButtonGroup(this)) // krazy:exclude=tipsandthis
+    , mGroupwareButtonGroup(new QButtonGroup(this)) // krazy:exclude=tipsandthis
 {
     setupUi(this);
 
-    mDaysButtonGroup = new QButtonGroup(this); // krazy:exclude=tipsandthis
     mDaysButtonGroup->addButton(mDateTodayButton, 0);
     mDaysButtonGroup->addButton(mDateMonthButton, 1);
     mDaysButtonGroup->addButton(mDateRangeButton, 2);
 
-    mShowButtonGroup = new QButtonGroup(this); // krazy:exclude=tipsandthis
     mShowButtonGroup->setExclusive(false);
     mShowButtonGroup->addButton(mShowBirthdaysFromCal);
     mShowButtonGroup->addButton(mShowAnniversariesFromCal);
 
-    mGroupwareButtonGroup = new QButtonGroup(this); // krazy:exclude=tipsandthis
     mGroupwareButtonGroup->setExclusive(false);
     mGroupwareButtonGroup->addButton(mShowMineOnly);
 
     customDaysChanged(7);
 
     // Remove QOverload<QAbstractButton *> when we switch on qt6. For the moment it avoids to add an #ifdef
-    connect(mDaysButtonGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &KCMApptSummary::modified);
-    connect(mShowButtonGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &KCMApptSummary::modified);
-    connect(mGroupwareButtonGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &KCMApptSummary::modified);
+    connect(mDaysButtonGroup, &QButtonGroup::buttonClicked, this, &KCMApptSummary::modified);
+    connect(mShowButtonGroup, &QButtonGroup::buttonClicked, this, &KCMApptSummary::modified);
+    connect(mGroupwareButtonGroup, &QButtonGroup::buttonClicked, this, &KCMApptSummary::modified);
 
-    connect(mDaysButtonGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &KCMApptSummary::buttonClicked);
+    connect(mDaysButtonGroup, &QButtonGroup::buttonClicked, this, &KCMApptSummary::buttonClicked);
 
-    connect(mCustomDays, QOverload<int>::of(&QSpinBox::valueChanged), this, &KCMApptSummary::modified);
-    connect(mCustomDays, QOverload<int>::of(&QSpinBox::valueChanged), this, &KCMApptSummary::customDaysChanged);
+    connect(mCustomDays, &QSpinBox::valueChanged, this, &KCMApptSummary::modified);
+    connect(mCustomDays, &QSpinBox::valueChanged, this, &KCMApptSummary::customDaysChanged);
 
     KAcceleratorManager::manage(this);
 
