@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORGANIZER_PLUGIN_H
-#define KORGANIZER_PLUGIN_H
+#pragma once
 
 #include <KontactInterface/Plugin>
 
@@ -54,4 +53,3 @@ private:
     KontactInterface::UniqueAppWatcher *mUniqueAppWatcher = nullptr;
 };
 
-#endif
