@@ -10,7 +10,7 @@
 
 #include "summaryeventinfo.h"
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Calendar>
 #include <KCalendarCore/Event>
@@ -70,7 +70,7 @@ SummaryEventInfo::SummaryEventInfo()
 }
 
 /**static*/
-SummaryEventInfo::List SummaryEventInfo::eventsForRange(const QDate &start, const QDate &end, const Akonadi::ETMCalendar::Ptr &calendar)
+SummaryEventInfo::List SummaryEventInfo::eventsForRange(QDate start, QDate end, const Akonadi::ETMCalendar::Ptr &calendar)
 {
     KCalendarCore::Event::List allEvents = calendar->events();
     KCalendarCore::Event::List events;
@@ -213,6 +213,9 @@ SummaryEventInfo::List SummaryEventInfo::eventsForRange(const QDate &start, cons
             str.append(QStringLiteral(" (%1/%2)").arg(dayof).arg(span));
         }
         summaryEvent->summaryText = str;
+        if (!ev->location().isEmpty()) {
+            summaryEvent->summaryText.append(QStringLiteral(" (%1)").arg(ev->location()));
+        }
         summaryEvent->summaryUrl = ev->uid();
 
         QString displayName;
@@ -261,7 +264,7 @@ SummaryEventInfo::List SummaryEventInfo::eventsForRange(const QDate &start, cons
     return eventInfoList;
 }
 
-SummaryEventInfo::List SummaryEventInfo::eventsForDate(const QDate &date, const Akonadi::ETMCalendar::Ptr &calendar)
+SummaryEventInfo::List SummaryEventInfo::eventsForDate(QDate date, const Akonadi::ETMCalendar::Ptr &calendar)
 {
     return eventsForRange(date, date, calendar);
 }
