@@ -14,8 +14,8 @@
 #include <CalendarSupport/Utils>
 
 #include <Akonadi/Calendar/IncidenceChanger>
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/ItemFetchScope>
+#include <Akonadi/Collection>
+#include <Akonadi/ItemFetchScope>
 
 #include <KCalUtils/IncidenceFormatter>
 
@@ -148,8 +148,6 @@ void TodoSummaryWidget::updateView()
     //     not-started (no start date and 0% completed)
 
     int counter = 0;
-    QLabel *label = nullptr;
-
     if (!prList.isEmpty()) {
         QPixmap pm = QIcon::fromTheme(QStringLiteral("view-calendar-tasks")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
 
@@ -168,7 +166,7 @@ void TodoSummaryWidget::updateView()
             */
 
             // Icon label
-            label = new QLabel(this);
+            auto label = new QLabel(this);
             label->setPixmap(pm);
             label->setMaximumWidth(label->minimumSizeHint().width());
             mLayout->addWidget(label, counter, 0);
@@ -368,7 +366,8 @@ bool TodoSummaryWidget::startsToday(const KCalendarCore::Todo::Ptr &todo)
 
 const QString TodoSummaryWidget::stateStr(const KCalendarCore::Todo::Ptr &todo)
 {
-    QString str1, str2;
+    QString str1;
+    QString str2;
 
     if (todo->isOpenEnded()) {
         str1 = i18n("open-ended");
