@@ -31,7 +31,6 @@
 #include <KToolBar>
 #include <QLabel>
 #include <QStatusBar>
-#include <kxmlgui_version.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -41,6 +40,7 @@
 KOrganizer::KOrganizer()
     : KParts::MainWindow()
     , KOrg::MainWindow()
+    , mCalendarView(new CalendarView(this))
 {
     // Set this to be the group leader for all subdialogs - this means
     // modal subdialogs will only affect this dialog, not the other windows
@@ -49,7 +49,6 @@ KOrganizer::KOrganizer()
     KOCore::self()->addXMLGUIClient(this, this);
     //  setMinimumSize(600,400);  // make sure we don't get resized too small...
 
-    mCalendarView = new CalendarView(this);
     mCalendarView->setObjectName(QStringLiteral("KOrganizer::CalendarView"));
     setCentralWidget(mCalendarView);
 
@@ -78,7 +77,6 @@ void KOrganizer::init(bool document)
     mActionManager->createCalendarAkonadi();
 
     mActionManager->init();
-    mActionManager->loadParts();
 
     KOrganizerPluginInterface::self()->setActionCollection(actionCollection());
     KOrganizerPluginInterface::self()->initializePlugins();
@@ -175,11 +173,7 @@ void KOrganizer::initActions()
 
 void KOrganizer::slotEditKeys()
 {
-#if KXMLGUI_VERSION < QT_VERSION_CHECK(5,84,0)
-    KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed);
-#else
     KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed);
-#endif
 }
 
 bool KOrganizer::queryClose()
