@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_KORGANIZER_OPTIONS_H
-#define KORG_KORGANIZER_OPTIONS_H
+#pragma once
 
 #include <KLocalizedString>
 #include <QCommandLineParser>
@@ -30,4 +29,3 @@ static void korganizer_options(QCommandLineParser *parser)
 #endif
 }
 
-#endif
