@@ -9,9 +9,10 @@
 
 #include "koprefsdialogcolorsandfonts.h"
 #include "koprefs.h"
-#include <AkonadiCore/EntityTreeModel>
+#include <Akonadi/CollectionComboBox>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/TagSelectionComboBox>
 #include <CalendarSupport/KCalPrefs>
-#include <CollectionComboBox>
 #include <KColorButton>
 #include <KComboBox>
 #include <KLocalizedString>
@@ -23,14 +24,13 @@
 #include <QLabel>
 #include <QPushButton>
 #include <QTabWidget>
-#include <TagSelectionComboBox>
 
 K_PLUGIN_CLASS_WITH_JSON(KOPrefsDialogColorsAndFonts, "korganizer_configcolorsandfonts.json")
 
 KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent, const QVariantList &args)
     : Korganizer::KPrefsModule(KOPrefs::instance(), parent, args)
 {
-    QBoxLayout *topTopLayout = new QVBoxLayout(this);
+    auto topTopLayout = new QVBoxLayout(this);
     auto tabWidget = new QTabWidget(this);
     topTopLayout->addWidget(tabWidget);
 
@@ -104,7 +104,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent, const
                                        "Select the tag you want to modify. "
                                        "You can change the selected tag's color using "
                                        "the adjacent color button."));
-    connect(mCategoryCombo, qOverload<int>(&KComboBox::activated), this, &KOPrefsDialogColorsAndFonts::updateCategoryColor);
+    connect(mCategoryCombo, &KComboBox::activated, this, &KOPrefsDialogColorsAndFonts::updateCategoryColor);
     categoryLayout->addWidget(mCategoryCombo, 1, 0);
 
     mCategoryButton = new KColorButton(categoryGroup);
