@@ -7,9 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KOPREFSDIALOGCOLORSANDFONTS_H
-#define KOPREFSDIALOGCOLORSANDFONTS_H
-#include "kcm_korganizer_export.h"
+#pragma once
 #include "kprefsdialog.h"
 #include <QWidget>
 
@@ -24,7 +22,7 @@ class KOPrefsDialogColorsAndFonts : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-    explicit KOPrefsDialogColorsAndFonts(QWidget *parent);
+    explicit KOPrefsDialogColorsAndFonts(QWidget *parent, const QVariantList &args);
 
 protected:
     void usrWriteConfig() override;
@@ -53,4 +51,3 @@ private:
     QList<KColorButton *> mButtonsDisable; // button that are disabled when using system color
 };
 
-#endif // KOPREFSDIALOGCOLORSANDFONTS_H
