@@ -11,18 +11,21 @@
 #include "prefs/koprefs.h"
 #include <CalendarSupport/KCalPrefs>
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <QCheckBox>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <TransportManagementWidget>
 #include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
 
-KOPrefsDialogGroupScheduling::KOPrefsDialogGroupScheduling(QWidget *parent)
-    : Korganizer::KPrefsModule(KOPrefs::instance(), parent)
-{
-    QBoxLayout *topTopLayout = new QVBoxLayout(this);
+K_PLUGIN_CLASS_WITH_JSON(KOPrefsDialogGroupScheduling, "korganizer_configgroupscheduling.json")
 
-    QWidget *topFrame = new QWidget(this);
+KOPrefsDialogGroupScheduling::KOPrefsDialogGroupScheduling(QWidget *parent, const QVariantList &args)
+    : Korganizer::KPrefsModule(KOPrefs::instance(), parent, args)
+{
+    auto topTopLayout = new QVBoxLayout(this);
+
+    auto topFrame = new QWidget(this);
     topTopLayout->addWidget(topFrame);
 
     auto topLayout = new QGridLayout(topFrame);
@@ -51,9 +54,4 @@ void KOPrefsDialogGroupScheduling::usrWriteConfig()
 {
 }
 
-extern "C" {
-Q_DECL_EXPORT KCModule *create_korganizerconfiggroupscheduling(QWidget *parent, const char *)
-{
-    return new KOPrefsDialogGroupScheduling(parent);
-}
-}
+#include "koprefsdialoggroupscheduling.moc"
