@@ -28,7 +28,7 @@ public:
 protected Q_SLOTS:
     void usrWriteConfig() override;
     void usrReadConfig() override;
-    void configure();
+    void configureClicked(QAction *action);
     void selectionChanged();
     void positioningChanged();
 
@@ -41,7 +41,6 @@ private:
     QRadioButton *mPositionAgendaTop = nullptr;
     QRadioButton *mPositionAgendaBottom = nullptr;
     QTreeWidgetItem *mDecorations = nullptr;
-    QTreeWidgetItem *mOthers = nullptr;
     QSet<QString> mDecorationsAtMonthViewTop;
     QSet<QString> mDecorationsAtAgendaViewTop;
     QSet<QString> mDecorationsAtAgendaViewBottom;
