@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KOPREFSDIALOGVIEWS_H
-#define KOPREFSDIALOGVIEWS_H
+#pragma once
 
 #include "kprefsdialog.h"
 
@@ -17,7 +16,7 @@ class KItemIconCheckCombo;
 class KOPrefsDialogViews : public Korganizer::KPrefsModule
 {
 public:
-    explicit KOPrefsDialogViews(QWidget *parent);
+    explicit KOPrefsDialogViews(QWidget *parent, const QVariantList &args = {});
 
 protected:
     void usrReadConfig() override;
@@ -27,4 +26,3 @@ private:
     KItemIconCheckCombo *mAgendaIconComboBox;
 };
 
-#endif // KOPREFSDIALOGVIEWS_H
