@@ -13,6 +13,10 @@
 
 #include <CalendarSupport/CalPrinter>
 
+#include <memory>
+
+class KOAgendaViewPrivate;
+
 /**
   KOAgendaView is the agenda-like view that displays events in a single
   or multi-day view.
@@ -94,7 +98,6 @@ Q_SIGNALS:
     void timeSpanSelectionChanged();
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<KOAgendaViewPrivate> const d;
 };
 
