@@ -161,10 +161,6 @@ bool ReparentingModel::validateNode(const Node *node) const
     const Node *n = node;
     int depth = 0;
     while (n) {
-        if (!n) {
-            qCWarning(KORGANIZER_LOG) << "nullptr" << depth;
-            return false;
-        }
         if ((intptr_t)(n) < 1000) {
             // Detect corruptions with unlikely pointers
             qCWarning(KORGANIZER_LOG) << "corrupt pointer" << depth;
@@ -307,7 +303,8 @@ void ReparentingModel::setNodes(const QList<Node::Ptr> &nodes)
     for (const ReparentingModel::Node::Ptr &node : nodes) {
         addNode(node);
     }
-    Q_FOREACH (const ReparentingModel::Node::Ptr &node, mProxyNodes) {
+    const auto currentProxyNodes = mProxyNodes;
+    for (const ReparentingModel::Node::Ptr &node : currentProxyNodes) {
         if (!nodes.contains(node)) {
             removeNode(*node);
         }
