@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
-#ifndef KORG_REPARENTINGMODEL_H
-#define KORG_REPARENTINGMODEL_H
+#pragma once
 
 #include <QAbstractProxyModel>
 #include <QSharedPointer>
@@ -146,4 +145,3 @@ private:
     NodeManager::Ptr mNodeManager;
 };
 
-#endif
