@@ -16,8 +16,12 @@
 
 #include <QAbstractItemModel>
 
+#include <memory>
+
 namespace KOrg
 {
+class MultiAgendaViewPrivate;
+
 /**
   Shows one agenda for every resource side-by-side.
 */
@@ -68,10 +72,11 @@ public Q_SLOTS:
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<MultiAgendaViewPrivate> const d;
 };
 
+class MultiAgendaViewConfigDialogPrivate;
+
 class MultiAgendaViewConfigDialog : public QDialog, public EventViews::ConfigDialogInterface
 {
     Q_OBJECT
@@ -103,8 +108,7 @@ private Q_SLOTS:
     void titleEdited(const QString &text);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<MultiAgendaViewConfigDialogPrivate> const d;
 };
 }
 
