@@ -10,8 +10,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_VIEWS_KOTIMELINEVIEW_H
-#define KORG_VIEWS_KOTIMELINEVIEW_H
+#pragma once
 
 #include "koeventview.h"
 
@@ -58,4 +57,3 @@ private:
     EventViews::TimelineView *mTimeLineView = nullptr;
 };
 
-#endif
